from setuptools import setup

setup(name='jwaigz-distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['jwaigz-distributions'],
      author='John Njeri',
      author_email ='waiganjojohn11@gmail.com',
      zip_safe=False)
